<div align = "center">
  <img src="https://raw.githubusercontent.com/mldsveda/PyScrappy/main/PyScrappy.png">
  <hr>
  <br/>
</div>

## PyScrappy: powerful Python data scraping toolkit

[![forthebadge made-with-python](http://ForTheBadge.com/images/badges/made-with-python.svg)](https://www.python.org/)    

[![Python 3.6](https://img.shields.io/badge/python-3.6-blue.svg)](https://www.python.org/downloads/release/python-360/) 
[![PyPI Latest Release](https://img.shields.io/pypi/v/PyScrappy.svg)](https://pypi.org/project/PyScrappy/)
[![Conda Latest Release](https://anaconda.org/conda-forge/pandas/badges/version.svg)](https://anaconda.org/anaconda/pandas/)

[![Package Status](https://img.shields.io/pypi/status/PyScrappy.svg)](https://pypi.org/project/PyScrappy/)
[![License](https://img.shields.io/pypi/l/PyScrappy.svg)](https://github.com/mldsveda/PyScrappy/blob/main/LICENSE)
![](https://img.shields.io/pypi/dm/PyScrappy)

![](https://komarev.com/ghpvc/?username=mldsveda&style=flat-square)
![stars](https://img.shields.io/github/stars/mldsveda/PyScrappy?style=social)
![forks](https://img.shields.io/github/forks/mldsveda/PyScrappy?style=social)

[![](https://img.shields.io/badge/pyscrappy-official%20documentation-blue)](https://pyscrappy.netlify.app/)


## What is it?

**PyScrappy** is a Python package that provides a fast, flexible, and exhaustive way to scrape data from various different sources. Being an
easy and intuitive library. It aims to be the fundamental high-level building block for scraping **data** in Python. Additionally, it has the broader goal of becoming **the most powerful and flexible open source data scraping tool available**.

## Main Features
Here are just a few of the things that PyScrappy does well:

  - Easy scraping of [**Data**](https://medium.com/analytics-vidhya/web-scraping-in-python-using-the-all-new-pyscrappy-5c136ed6906b) available on the internet
  - Returns a [**DataFrame**](https://pandas.pydata.org/docs/reference/api/pandas.DataFrame.html) for further analysis and research purposes.
  - Automatic [**Data Scraping**](https://medium.com/analytics-vidhya/web-scraping-in-python-using-the-all-new-pyscrappy-5c136ed6906b): Other than a few user input parameters the whole process of scraping the data is automatic.
  - Powerful, flexible 

## Where to get it
The source code is currently hosted on GitHub at:
https://github.com/mldsveda/PyScrappy

Binary installers for the latest released version are available at the [Python
Package Index (PyPI)](https://pypi.org/project/PyScrappy/).

```sh
pip install PyScrappy
```

## Dependencies
- [selenium - Selenium is a free (open-source) automated testing framework used to validate web applications across different browsers and platforms.](https://www.selenium.dev/)
- [webdriver-manger - WebDriverManager is an API that allows users to automate the handling of driver executables like chromedriver.exe, geckodriver.exe etc required by Selenium WebDriver API. Now let us see, how can we set path for driver executables for different browsers like Chrome, Firefox etc.](https://github.com/bonigarcia/webdrivermanager)
- [beautifulsoup4 - Beautiful Soup is a Python library for getting data out of HTML, XML, and other markup languages.](https://www.crummy.com/software/BeautifulSoup/bs4/doc/)
- [pandas - Pandas is a fast, powerful, flexible and easy to use open source data analysis and manipulation tool, built on top of the Python programming language.](https://pandas.pydata.org/)


## License
[MIT](https://github.com/mldsveda/PyScrappy/blob/main/LICENSE)

## Getting Help

For usage questions, the best place to go to is [StackOverflow](https://stackoverflow.com/questions/tagged/pyscrappy).
Further, general questions and discussions can also take place on GitHub in this [repository](https://github.com/mldsveda/PyScrappy).

## Discussion and Development
Most development discussions take place on GitHub in this [repository](https://github.com/mldsveda/PyScrappy).

Also visit the official documentation of [PyScrappy](https://pyscrappy.netlify.app/) for more information.

## Contributing to PyScrappy
All contributions, bug reports, bug fixes, documentation improvements, enhancements, and ideas are welcome.

If you are simply looking to start working with the PyScrappy codebase, navigate to the [GitHub "issues" tab](https://github.com/mldsveda/PyScrappy/issues) and start looking through interesting issues.

## End Notes
*Learn More about this package on [Medium](https://medium.com/analytics-vidhya/web-scraping-in-python-using-the-all-new-pyscrappy-5c136ed6906b).*

### ***This package is solely made for educational and research purposes.***
